# types-pefile

[![PyPI](https://img.shields.io/pypi/v/types-pefile.svg)](https://pypi.org/project/types-pefile/)
[![License](https://img.shields.io/pypi/l/types-pefile.svg)](https://github.com/coloursofnoise/types-pefile/blob/main/LICENSE)

This package aims to provide exhaustive type annotations for [`pefile`](https://github.com/erocarrera/pefile).

Type stubs are tested against [`pyright`](https://github.com/microsoft/pyright) and [`mypy`](https://github.com/python/mypy).


## Usage
Install using `pip`:
```console
$ pip install types-pefile
```
For older releases of `pefile`, download the corresponding version of `types-pefile`, if available:
```console
$ pip install types-pefile<=2022.5.30
```


## Versioning
Distributions of this package follow the release versions for `pefile`, with an added suffix for revisions on a particular release.